==> kubernetes-model-admissionregistration-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/authentication/v1alpha1/SelfSubjectReviewStatusFluent.java <==
package io.fabric8.kubernetes.api.model.authentication.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.authentication.UserInfo;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.authentication.UserInfoFluent;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface SelfSubjectReviewStatusFluent<A extends SelfSubjectReviewStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo();
  public UserInfo buildUserInfo();
  public A withUserInfo(UserInfo userInfo);
  public Boolean hasUserInfo();
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> withNewUserInfo();
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> withNewUserInfoLike(UserInfo item);
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editUserInfo();
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editOrNewUserInfo();
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface UserInfoNested<N> extends Nested<N>,UserInfoFluent<SelfSubjectReviewStatusFluent.UserInfoNested<N>>{
    public N and();
    public N endUserInfo();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/authentication/v1alpha1/SelfSubjectReviewStatusFluent.java <==
package io.fabric8.kubernetes.api.model.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.authentication.UserInfo;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.authentication.UserInfoFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SelfSubjectReviewStatusFluent<A extends SelfSubjectReviewStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo();
  public UserInfo buildUserInfo();
  public A withUserInfo(UserInfo userInfo);
  public Boolean hasUserInfo();
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> withNewUserInfo();
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> withNewUserInfoLike(UserInfo item);
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editUserInfo();
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editOrNewUserInfo();
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface UserInfoNested<N> extends Nested<N>,UserInfoFluent<SelfSubjectReviewStatusFluent.UserInfoNested<N>>{
    public N and();
    public N endUserInfo();
    
  }
  
}
